==> haskell-src-meta-0.8.9-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src-meta
version:              0.8.9
visibility:           public
id:                   haskell-src-meta-0.8.9-BjW2tGpsHenHv8Qcqc3Ksx
key:                  haskell-src-meta-0.8.9-BjW2tGpsHenHv8Qcqc3Ksx
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  3c33cfe0a53a286c4d3657cd7b262e92
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/haskell-src-meta-0.8.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/haskell-src-meta-0.8.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.9-BjW2tGpsHenHv8Qcqc3Ksx
depends:
    base-4.15.1.0 haskell-src-exts-1.23.1-7IUjIfCyZmWFtQWj8e0y9b
    pretty-1.1.3.6 syb-0.7.2.1-ik7SGoPZsVGet7fZLM3W2
    template-haskell-2.17.0.0 th-orphans-0.13.12-LQmzJkR5hel8LwLfycZdnv

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.8.9-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src-meta
version:              0.8.9
visibility:           public
id:                   haskell-src-meta-0.8.9-47jIaeSFoa1Fs0P1PCRp8o
key:                  haskell-src-meta-0.8.9-47jIaeSFoa1Fs0P1PCRp8o
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  0d4d43cb93e36b6245918f66a560fb06
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/haskell-src-meta-0.8.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/haskell-src-meta-0.8.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.9-47jIaeSFoa1Fs0P1PCRp8o
depends:
    base-4.15.1.0 haskell-src-exts-1.23.1-5UuP9UcDBzQ1Vl0KyL6svq
    pretty-1.1.3.6 syb-0.7.2.1-BqdTZk7PNzEBis7awJ90S6
    template-haskell-2.17.0.0 th-orphans-0.13.12-1quxfibiRsYDQxS8HSIac

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
